Build from source 100x slower than prod
#9
Apologies on the delay here, but here are the two outputs:

First, from the website:
Code:
hashcat (v6.1.1) starting in benchmark mode... Benchmarking uses hand-optimized kernel code by default. You can use it in your cracking session by setting the -O option. Note: Using optimized kernel code limits the maximum supported password length. To disable the optimized kernel code in benchmark mode, use the -w option. Kernel /usr/local/share/hashcat/OpenCL/m08900-optimized.cl: Optimized kernel requested but not needed - falling back to pure kernel CUDA API (CUDA 11.2) ==================== * Device #1: GeForce RTX 2080 Ti, 10862/11019 MB, 68MCU OpenCL API (OpenCL 1.2 CUDA 11.2.109) - Platform #1 [NVIDIA Corporation] ======================================================================== * Device #2: GeForce RTX 2080 Ti, skipped Benchmark relevant options: =========================== * --optimized-kernel-enable Hashmode: 8900 - scrypt (Iterations: 1) Speed.#1.........:  709.5 kH/s (24.24ms) @ Accel:16 Loops:1 Thr:16 Vec:1 Started: Sun Apr 25 21:56:35 2021 Stopped: Sun Apr 25 21:56:42 2021

Second, from building from source:
Code:
hashcat (v6.1.1-248-g62fc3601b) starting in benchmark mode... Benchmarking uses hand-optimized kernel code by default. You can use it in your cracking session by setting the -O option. Note: Using optimized kernel code limits the maximum supported password length. To disable the optimized kernel code in benchmark mode, use the -w option. CUDA API (CUDA 11.2) ==================== * Device #1: GeForce RTX 2080 Ti, 10862/11019 MB, 68MCU OpenCL API (OpenCL 1.2 CUDA 11.2.109) - Platform #1 [NVIDIA Corporation] ======================================================================== * Device #2: GeForce RTX 2080 Ti, skipped Benchmark relevant options: =========================== * --optimized-kernel-enable Hashmode: 8900 - scrypt (Iterations: 1) Speed.#1.........:    1344 H/s (1618.40ms) @ Accel:68 Loops:1 Thr:32 Vec:1 Started: Sun Apr 25 21:57:38 2021 Stopped: Sun Apr 25 21:57:49 2021

Both were run with "hashcat -b -m 8900"
Reply


Messages In This Thread
RE: Build from source 100x slower than prod - by thaas - 04-25-2021, 11:58 PM